## Authors

`gridspeccer` was foolishly started by:

* **Oliver Breitwieser** `oliver@breitwieser.eu`

The following people contributed to the code:

* **Julian Goeltz** `julian.goeltz@kip.uni-heidelberg.de`

